@@ -1,9 +1,9 @@
 /*-------------------------------------------------------------------------
  *
- * Copyright (c) 2006-2008, PostgreSQL Global Development Group
+ * Copyright (c) 2006-2011, PostgreSQL Global Development Group
  *
  * IDENTIFICATION
- *   $PostgreSQL: pgjdbc/org/postgresql/core/VisibleBufferedInputStream.java,v 1.3 2008/01/08 06:56:27 jurka Exp $
+ *   $PostgreSQL: pgjdbc/org/postgresql/core/VisibleBufferedInputStream.java,v 1.5 2011/08/02 13:40:12 davecramer Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -76,6 +76,16 @@ public class VisibleBufferedInputStream extends InputStream {
         return -1;
     }
 
+    /**
+     * Reads a byte from the buffer without advancing the index pointer.
+     */
+    public int peek() throws IOException {
+        if (ensureBytes(1)) {
+            return buffer[index] & 0xFF;
+        }
+        return -1;
+    }
+
     /**
      * Reads byte from the buffer without any checks. This method never
      * reads from the underlaying stream.
