@@ -1,10 +1,10 @@
 /*-------------------------------------------------------------------------
 *
-* Copyright (c) 2004-2005, PostgreSQL Global Development Group
+* Copyright (c) 2004-2011, PostgreSQL Global Development Group
 * Copyright (c) 2004, Open Cloud Limited.
 *
 * IDENTIFICATION
-*   $PostgreSQL: pgjdbc/org/postgresql/core/v2/SimpleParameterList.java,v 1.9 2006/12/01 08:53:45 jurka Exp $
+*   $PostgreSQL: pgjdbc/org/postgresql/core/v2/SimpleParameterList.java,v 1.12 2011/08/02 13:40:12 davecramer Exp $
 *
 *-------------------------------------------------------------------------
 */
@@ -67,7 +67,7 @@ class SimpleParameterList implements ParameterList {
         if (useEStringSyntax)
             sbuf.append(' ').append('E');
         sbuf.append('\'');
-        Utils.appendEscapedString(sbuf, value, false);
+        Utils.appendEscapedLiteral(sbuf, value, false);
         sbuf.append('\'');
 
         setLiteralParameter(index, sbuf.toString(), oid);
