@@ -1,10 +1,10 @@
 /*-------------------------------------------------------------------------
 *
-* Copyright (c) 2004-2005, PostgreSQL Global Development Group
+* Copyright (c) 2004-2011, PostgreSQL Global Development Group
 * Copyright (c) 2004, Open Cloud Limited.
 *
 * IDENTIFICATION
-*   $PostgreSQL: pgjdbc/org/postgresql/core/v3/CompositeParameterList.java,v 1.9 2006/05/22 09:52:37 jurka Exp $
+*   $PostgreSQL: pgjdbc/org/postgresql/core/v3/CompositeParameterList.java,v 1.12 2011/08/02 13:40:12 davecramer Exp $
 *
 *-------------------------------------------------------------------------
 */
@@ -135,6 +135,12 @@ class CompositeParameterList implements V3ParameterList {
             subparams[sub].checkAllParametersSet();
     }
 
+    public void convertFunctionOutParameters()
+    {
+        for (int sub = 0; sub < subparams.length; ++sub)
+            subparams[sub].convertFunctionOutParameters();
+    }
+
     private final int total;
     private final SimpleParameterList[] subparams;
     private final int[] offsets;
