@@ -1,10 +1,10 @@
 /*-------------------------------------------------------------------------
 *
-* Copyright (c) 2003-2008, PostgreSQL Global Development Group
+* Copyright (c) 2003-2011, PostgreSQL Global Development Group
 * Copyright (c) 2004, Open Cloud Limited.
 *
 * IDENTIFICATION
-*   $PostgreSQL: pgjdbc/org/postgresql/core/v3/QueryExecutorImpl.java,v 1.45.2.2 2009/12/07 22:03:14 jurka Exp $
+*   $PostgreSQL: pgjdbc/org/postgresql/core/v3/QueryExecutorImpl.java,v 1.54 2011/08/02 13:40:12 davecramer Exp $
 *
 *-------------------------------------------------------------------------
 */
@@ -714,6 +714,9 @@ public class QueryExecutorImpl implements QueryExecutor {
         byte buf[] = Utils.encodeUTF8(sql);
 
         try {
+            if (logger.logDebug())
+                logger.debug(" FE=> Query(CopyStart)");
+
             pgStream.SendChar('Q');
             pgStream.SendInteger4(buf.length + 4 + 1);
             pgStream.Send(buf);
@@ -813,6 +816,9 @@ public class QueryExecutorImpl implements QueryExecutor {
                 throw new PSQLException(GT.tr("Tried to end inactive copy"), PSQLState.OBJECT_NOT_IN_STATE);
 
         try {
+            if (logger.logDebug())
+                logger.debug(" FE=> CopyDone");
+
             pgStream.SendChar('c'); // CopyDone
             pgStream.SendInteger4(4);
             pgStream.flush();
@@ -838,7 +844,7 @@ public class QueryExecutorImpl implements QueryExecutor {
             throw new PSQLException(GT.tr("Tried to write to an inactive copy operation"), PSQLState.OBJECT_NOT_IN_STATE);
 
         if (logger.logDebug())
-            logger.debug(" FE=> CopyData(" + (siz-off) + ")");
+            logger.debug(" FE=> CopyData(" + siz + ")");
 
         try {
             pgStream.SendChar('d');
@@ -900,6 +906,25 @@ public class QueryExecutorImpl implements QueryExecutor {
         int len;
 
         while( !endReceiving && (block || pgStream.hasMessagePending()) ) {
+
+            // There is a bug in the server's implementation of the copy
+            // protocol.  It returns command complete immediately upon
+            // receiving the EOF marker in the binary protocol,
+            // potentially before we've issued CopyDone.  When we are not
+            // blocking, we don't think we are done, so we hold off on
+            // processing command complete and any subsequent messages
+            // until we actually are done with the copy.
+            //
+            if (!block) {
+                int c = pgStream.PeekChar();
+                if (c == 'C') // CommandComplete
+                {
+                    if (logger.logDebug())
+                        logger.debug(" <=BE CommandStatus, Ignored until CopyDone");
+                    break;
+                }
+            }
+
             int c = pgStream.ReceiveChar();
             switch(c) {
 
@@ -980,7 +1005,7 @@ public class QueryExecutorImpl implements QueryExecutor {
                     error = new PSQLException(GT.tr("Got CopyData without an active copy operation"), PSQLState.OBJECT_NOT_IN_STATE);
                 } else if (!(op instanceof CopyOutImpl)) {
                     error = new PSQLException(GT.tr("Unexpected copydata from server for {0}",
-                            op == null ? "null" : op.getClass().getName()), PSQLState.COMMUNICATION_ERROR);
+                            op.getClass().getName()), PSQLState.COMMUNICATION_ERROR);
                 } else {
                     ((CopyOutImpl)op).handleCopydata(buf);
                 }
@@ -1055,11 +1080,12 @@ public class QueryExecutorImpl implements QueryExecutor {
         // Now the query itself.
         SimpleQuery[] subqueries = query.getSubqueries();
         SimpleParameterList[] subparams = parameters.getSubparams();
+        boolean disallowBatching = (flags & QueryExecutor.QUERY_DISALLOW_BATCHING) != 0;
 
         if (subqueries == null)
         {
             ++queryCount;
-            if (queryCount >= MAX_BUFFERED_QUERIES)
+            if (disallowBatching || queryCount >= MAX_BUFFERED_QUERIES)
             {
                 sendSync();
                 processResults(trackingHandler, flags);
@@ -1076,7 +1102,7 @@ public class QueryExecutorImpl implements QueryExecutor {
             for (int i = 0; i < subqueries.length; ++i)
             {
                 ++queryCount;
-                if (queryCount >= MAX_BUFFERED_QUERIES)
+                if (disallowBatching || queryCount >= MAX_BUFFERED_QUERIES)
                 {
                     sendSync();
                     processResults(trackingHandler, flags);
@@ -1843,10 +1869,10 @@ public class QueryExecutorImpl implements QueryExecutor {
                     if (logger.logDebug())
                         logger.debug(" <=BE ParameterStatus(" + name + " = " + value + ")");
 
-                    if (name.equals("client_encoding") && !(value.equalsIgnoreCase("UNICODE") || value.equalsIgnoreCase("UTF8")) && !allowEncodingChanges)
+                    if (name.equals("client_encoding") && !value.equalsIgnoreCase("UTF8") && !allowEncodingChanges)
                     {
                         protoConnection.close(); // we're screwed now; we can't trust any subsequent string.
-                        handler.handleError(new PSQLException(GT.tr("The server''s client_encoding parameter was changed to {0}. The JDBC driver requires client_encoding to be UNICODE for correct operation.", value), PSQLState.CONNECTION_FAILURE));
+                        handler.handleError(new PSQLException(GT.tr("The server''s client_encoding parameter was changed to {0}. The JDBC driver requires client_encoding to be UTF8 for correct operation.", value), PSQLState.CONNECTION_FAILURE));
                         endQuery = true;
                     }
 
@@ -2042,7 +2068,7 @@ public class QueryExecutorImpl implements QueryExecutor {
             int typeModifier = pgStream.ReceiveInteger4();
             int formatType = pgStream.ReceiveInteger2();
             fields[i] = new Field(columnLabel,
-                                  null,  /* name not yet determined */
+                                  "",  /* name not yet determined */
                                   typeOid, typeLength, typeModifier, tableOid, positionInTable);
             fields[i].setFormat(formatType);
         }
