@@ -1,10 +1,10 @@
 /*-------------------------------------------------------------------------
 *
-* Copyright (c) 2004-2005, PostgreSQL Global Development Group
+* Copyright (c) 2004-2011, PostgreSQL Global Development Group
 * Copyright (c) 2004, Open Cloud Limited.
 *
 * IDENTIFICATION
-*   $PostgreSQL: pgjdbc/org/postgresql/core/v3/V3ParameterList.java,v 1.5 2005/07/04 18:50:29 davec Exp $
+*   $PostgreSQL: pgjdbc/org/postgresql/core/v3/V3ParameterList.java,v 1.8 2011/08/02 13:40:12 davecramer Exp $
 *
 *-------------------------------------------------------------------------
 */
@@ -28,6 +28,12 @@ interface V3ParameterList extends ParameterList {
      */
     void checkAllParametersSet() throws SQLException;
 
+    /**
+     * Convert any function output parameters to the correct type (void)
+     * and set an ignorable value for it.
+     */
+    void convertFunctionOutParameters();
+
     /**
      * Return a list of the SimpleParameterList objects that
      * make up this parameter list. If this object is already a
