@@ -1,9 +1,9 @@
 /*-------------------------------------------------------------------------
 *
-* Copyright (c) 2004-2005, PostgreSQL Global Development Group
+* Copyright (c) 2004-2011, PostgreSQL Global Development Group
 *
 * IDENTIFICATION
-*   $PostgreSQL: pgjdbc/org/postgresql/jdbc2/AbstractJdbc2Blob.java,v 1.10 2006/11/05 05:58:22 jurka Exp $
+*   $PostgreSQL: pgjdbc/org/postgresql/jdbc2/AbstractJdbc2Blob.java,v 1.15 2011/08/02 13:48:35 davecramer Exp $
 *
 *-------------------------------------------------------------------------
 */
@@ -11,13 +11,12 @@ package org.postgresql.jdbc2;
 
 import java.sql.SQLException;
 
-import org.postgresql.PGConnection;
-import org.postgresql.largeobject.LargeObject;
+import org.postgresql.core.BaseConnection;
 
 public abstract class AbstractJdbc2Blob extends AbstractJdbc2BlobClob
 {
 
-    public AbstractJdbc2Blob(PGConnection conn, int oid) throws SQLException
+    public AbstractJdbc2Blob(BaseConnection conn, long oid) throws SQLException
     {
         super(conn, oid);
     }
