@@ -1,9 +1,9 @@
 /*-------------------------------------------------------------------------
 *
-* Copyright (c) 2004-2008, PostgreSQL Global Development Group
+* Copyright (c) 2004-2011, PostgreSQL Global Development Group
 *
 * IDENTIFICATION
-* $PostgreSQL: pgjdbc/org/postgresql/jdbc2/EscapedFunctions.java,v 1.12 2008/11/16 12:14:06 jurka Exp $
+* $PostgreSQL: pgjdbc/org/postgresql/jdbc2/EscapedFunctions.java,v 1.14 2011/08/02 13:48:35 davecramer Exp $
 *
 *-------------------------------------------------------------------------
 */
@@ -116,23 +116,25 @@ public class EscapedFunctions {
     
     
     /** storage for functions implementations */
-    private static Map functionMap = null;
-    
+    private static Map functionMap = createFunctionMap();
+
+    private static Map createFunctionMap() {
+    	Method[] arrayMeths = EscapedFunctions.class.getDeclaredMethods();
+        Map functionMap = new HashMap(arrayMeths.length*2);
+        for (int i=0;i<arrayMeths.length;i++){
+            Method meth = arrayMeths[i];
+            if (meth.getName().startsWith("sql"))
+                functionMap.put(meth.getName().toLowerCase(Locale.US),meth);
+        }
+	return functionMap;
+    }
+
     /**
      * get Method object implementing the given function
      * @param functionName name of the searched function
      * @return a Method object or null if not found
      */
     public static Method getFunction(String functionName){
-        if (functionMap==null){
-            Method[] arrayMeths = EscapedFunctions.class.getDeclaredMethods();
-            functionMap = new HashMap(arrayMeths.length*2);
-            for (int i=0;i<arrayMeths.length;i++){
-                Method meth = arrayMeths[i];
-                if (meth.getName().startsWith("sql"))
-                    functionMap.put(meth.getName().toLowerCase(Locale.US),meth);
-            }
-        }
         return (Method) functionMap.get("sql"+functionName.toLowerCase(Locale.US));
     }
 
