@@ -1,9 +1,9 @@
 /*-------------------------------------------------------------------------
 *
-* Copyright (c) 2004-2008, PostgreSQL Global Development Group
+* Copyright (c) 2004-2011, PostgreSQL Global Development Group
 *
 * IDENTIFICATION
-*   $PostgreSQL: pgjdbc/org/postgresql/jdbc3/AbstractJdbc3Connection.java,v 1.20 2009/07/01 01:29:38 jurka Exp $
+*   $PostgreSQL: pgjdbc/org/postgresql/jdbc3/AbstractJdbc3Connection.java,v 1.22 2011/08/02 13:49:01 davecramer Exp $
 *
 *-------------------------------------------------------------------------
 */
@@ -47,6 +47,8 @@ public abstract class AbstractJdbc3Connection extends org.postgresql.jdbc2.Abstr
      */
     public void setHoldability(int holdability) throws SQLException
     {
+        checkClosed();
+
         switch (holdability)
         {
         case ResultSet.CLOSE_CURSORS_AT_COMMIT:
@@ -75,6 +77,7 @@ public abstract class AbstractJdbc3Connection extends org.postgresql.jdbc2.Abstr
      */
     public int getHoldability() throws SQLException
     {
+        checkClosed();
         return rsHoldability;
     }
 
@@ -91,6 +94,7 @@ public abstract class AbstractJdbc3Connection extends org.postgresql.jdbc2.Abstr
      */
     public Savepoint setSavepoint() throws SQLException
     {
+        checkClosed();
         if (!haveMinimumServerVersion("8.0"))
             throw new PSQLException(GT.tr("Server versions prior to 8.0 do not support savepoints."), PSQLState.NOT_IMPLEMENTED);
         if (getAutoCommit())
@@ -122,6 +126,7 @@ public abstract class AbstractJdbc3Connection extends org.postgresql.jdbc2.Abstr
      */
     public Savepoint setSavepoint(String name) throws SQLException
     {
+        checkClosed();
         if (!haveMinimumServerVersion("8.0"))
             throw new PSQLException(GT.tr("Server versions prior to 8.0 do not support savepoints."), PSQLState.NOT_IMPLEMENTED);
         if (getAutoCommit())
@@ -156,6 +161,7 @@ public abstract class AbstractJdbc3Connection extends org.postgresql.jdbc2.Abstr
      */
     public void rollback(Savepoint savepoint) throws SQLException
     {
+        checkClosed();
         if (!haveMinimumServerVersion("8.0"))
             throw new PSQLException(GT.tr("Server versions prior to 8.0 do not support savepoints."), PSQLState.NOT_IMPLEMENTED);
 
@@ -177,6 +183,7 @@ public abstract class AbstractJdbc3Connection extends org.postgresql.jdbc2.Abstr
      */
     public void releaseSavepoint(Savepoint savepoint) throws SQLException
     {
+        checkClosed();
         if (!haveMinimumServerVersion("8.0"))
             throw new PSQLException(GT.tr("Server versions prior to 8.0 do not support savepoints."), PSQLState.NOT_IMPLEMENTED);
 
@@ -220,6 +227,7 @@ public abstract class AbstractJdbc3Connection extends org.postgresql.jdbc2.Abstr
             int resultSetHoldability) throws SQLException;
 
     public Statement createStatement(int resultSetType, int resultSetConcurrency) throws SQLException {
+        checkClosed();
         return createStatement(resultSetType, resultSetConcurrency, getHoldability());
     }
 
@@ -263,6 +271,7 @@ public abstract class AbstractJdbc3Connection extends org.postgresql.jdbc2.Abstr
     throws SQLException;
 
     public PreparedStatement prepareStatement(String sql, int resultSetType, int resultSetConcurrency) throws SQLException {
+        checkClosed();
         return prepareStatement(sql, resultSetType, resultSetConcurrency, getHoldability());
     }
 
@@ -305,6 +314,7 @@ public abstract class AbstractJdbc3Connection extends org.postgresql.jdbc2.Abstr
 
     public CallableStatement prepareCall(String sql, int resultSetType,
                                          int resultSetConcurrency) throws SQLException {
+        checkClosed();
         return prepareCall(sql, resultSetType, resultSetConcurrency, getHoldability());
     }
 
@@ -348,6 +358,7 @@ public abstract class AbstractJdbc3Connection extends org.postgresql.jdbc2.Abstr
     public PreparedStatement prepareStatement(String sql, int autoGeneratedKeys)
     throws SQLException
     {
+        checkClosed();
         if (autoGeneratedKeys != Statement.NO_GENERATED_KEYS)
             sql = AbstractJdbc3Statement.addReturning(this, sql, new String[]{"*"}, false);
 
@@ -405,6 +416,7 @@ public abstract class AbstractJdbc3Connection extends org.postgresql.jdbc2.Abstr
         if (columnIndexes == null || columnIndexes.length == 0)
             return prepareStatement(sql);
         
+        checkClosed();
         throw new PSQLException(GT.tr("Returning autogenerated keys is not supported."), PSQLState.NOT_IMPLEMENTED);
     }
 
