@@ -1,9 +1,9 @@
 /*-------------------------------------------------------------------------
 *
-* Copyright (c) 2004-2008, PostgreSQL Global Development Group
+* Copyright (c) 2004-2011, PostgreSQL Global Development Group
 *
 * IDENTIFICATION
-*   $PostgreSQL: pgjdbc/org/postgresql/jdbc4/AbstractJdbc4Statement.java,v 1.5 2008/10/08 18:24:05 jurka Exp $
+*   $PostgreSQL: pgjdbc/org/postgresql/jdbc4/AbstractJdbc4Statement.java,v 1.7 2011/08/02 13:49:23 davecramer Exp $
 *
 *-------------------------------------------------------------------------
 */
@@ -367,4 +367,29 @@ abstract class AbstractJdbc4Statement extends org.postgresql.jdbc3g.AbstractJdbc
         throw org.postgresql.Driver.notImplemented(this.getClass(), "unwrap(Class<T>)");
     }
 
+    public java.util.logging.Logger getParentLogger() throws SQLFeatureNotSupportedException
+    {
+        throw org.postgresql.Driver.notImplemented(this.getClass(), "getParentLogger()");
+    }
+
+    public void closeOnCompletion() throws SQLException
+    {
+        throw org.postgresql.Driver.notImplemented(this.getClass(), "closeOnCompletion()");
+    }
+
+    public boolean isCloseOnCompletion() throws SQLException
+    {
+        throw org.postgresql.Driver.notImplemented(this.getClass(), "isCloseOnCompletion()");
+    }
+
+    public <T> T getObject(int parameterIndex, Class<T> type) throws SQLException
+    {
+        throw org.postgresql.Driver.notImplemented(this.getClass(), "getObject(int, Class<T>)");
+    }
+
+    public <T> T getObject(String parameterName, Class<T> type) throws SQLException
+    {
+        throw org.postgresql.Driver.notImplemented(this.getClass(), "getObject(String, Class<T>)");
+    }
+
 }
