@@ -1,9 +1,9 @@
 /*-------------------------------------------------------------------------
 *
-* Copyright (c) 2004-2008, PostgreSQL Global Development Group
+* Copyright (c) 2004-2011, PostgreSQL Global Development Group
 *
 * IDENTIFICATION
-*   $PostgreSQL: pgjdbc/org/postgresql/test/jdbc2/DatabaseMetaDataTest.java,v 1.44.2.2 2009/12/09 01:06:41 jurka Exp $
+*   $PostgreSQL: pgjdbc/org/postgresql/test/jdbc2/DatabaseMetaDataTest.java,v 1.51 2011/08/02 13:50:29 davecramer Exp $
 *
 *-------------------------------------------------------------------------
 */
@@ -55,6 +55,11 @@ public class DatabaseMetaDataTest extends TestCase
             stmt.execute("CREATE OR REPLACE FUNCTION f3(IN a int, INOUT b varchar, OUT c timestamptz) AS $f$ BEGIN b := 'a'; c := now(); return; END; $f$ LANGUAGE 'plpgsql'");
         }
         stmt.execute("CREATE OR REPLACE FUNCTION f4(int) RETURNS testmetadata AS 'SELECT 1, ''a''::text, now(), ''c''::text, ''q''::text' LANGUAGE 'SQL'");
+
+        if (TestUtil.haveMinimumServerVersion(con, "7.3")) {
+            stmt.execute("CREATE DOMAIN nndom AS int not null");
+            stmt.execute("CREATE TABLE domaintable (id nndom)");
+        }
         stmt.close();
     }
 
@@ -80,6 +85,10 @@ public class DatabaseMetaDataTest extends TestCase
         if (TestUtil.haveMinimumServerVersion(con, "8.1")) {
             stmt.execute("DROP FUNCTION f3(int, varchar)");
         }
+        if (TestUtil.haveMinimumServerVersion(con, "7.3")) {
+            stmt.execute("DROP TABLE domaintable");
+            stmt.execute("DROP DOMAIN nndom");
+        }
 
         TestUtil.closeDB( con );
     }
@@ -414,6 +423,16 @@ public class DatabaseMetaDataTest extends TestCase
         assertTrue("Couldn't find SELECT priv on table testmetadata for " + TestUtil.getUser(), l_foundSelect);
     }
 
+    public void testNoTablePrivileges() throws SQLException
+    {
+        Statement stmt = con.createStatement();
+        stmt.execute("REVOKE ALL ON testmetadata FROM PUBLIC");
+        stmt.execute("REVOKE ALL ON testmetadata FROM " + TestUtil.getUser());
+        DatabaseMetaData dbmd = con.getMetaData();
+        ResultSet rs = dbmd.getTablePrivileges(null, null, "testmetadata");
+        assertTrue(!rs.next());
+    }
+
     public void testPrimaryKeys() throws SQLException
     {
         // At the moment just test that no exceptions are thrown KJ
@@ -482,6 +501,42 @@ public class DatabaseMetaDataTest extends TestCase
         rs.close();
     }
 
+    public void testNotNullDomainColumn() throws SQLException
+    {
+        if (!TestUtil.haveMinimumServerVersion(con, "7.3"))
+            return;
+
+        DatabaseMetaData dbmd = con.getMetaData();
+        ResultSet rs = dbmd.getColumns("", "", "domaintable", "");
+        assertTrue(rs.next());
+        assertEquals("id", rs.getString("COLUMN_NAME"));
+        assertEquals("NO", rs.getString("IS_NULLABLE"));
+        assertTrue(!rs.next());
+    }
+
+    public void testAscDescIndexInfo() throws SQLException
+    {
+        if (!TestUtil.haveMinimumServerVersion(con, "8.3"))
+            return;
+
+        Statement stmt = con.createStatement();
+        stmt.execute("CREATE INDEX idx_a_d ON testmetadata (id ASC, quest DESC)");
+        stmt.close();
+
+        DatabaseMetaData dbmd = con.getMetaData();
+        ResultSet rs = dbmd.getIndexInfo(null, null, "testmetadata", false, false);
+
+        assertTrue(rs.next());
+        assertEquals("idx_a_d", rs.getString("INDEX_NAME"));
+        assertEquals("id", rs.getString("COLUMN_NAME"));
+        assertEquals("A", rs.getString("ASC_OR_DESC"));
+
+        assertTrue(rs.next());
+        assertEquals("idx_a_d", rs.getString("INDEX_NAME"));
+        assertEquals("quest", rs.getString("COLUMN_NAME"));
+        assertEquals("D", rs.getString("ASC_OR_DESC"));
+    }
+
     public void testPartialIndexInfo() throws SQLException
     {
         Statement stmt = con.createStatement();
@@ -659,9 +714,6 @@ public class DatabaseMetaDataTest extends TestCase
 
     public void testSchemas() throws Exception
     {
-        if (!TestUtil.haveMinimumServerVersion(con, "7.3"))
-            return ;
-
         DatabaseMetaData dbmd = con.getMetaData();
         assertNotNull(dbmd);
 
