@@ -1,9 +1,9 @@
 /*-------------------------------------------------------------------------
 *
-* Copyright (c) 2004-2005, PostgreSQL Global Development Group
+* Copyright (c) 2004-2011, PostgreSQL Global Development Group
 *
 * IDENTIFICATION
-*   $PostgreSQL: pgjdbc/org/postgresql/test/jdbc2/MiscTest.java,v 1.20 2005/12/02 03:05:10 jurka Exp $
+*   $PostgreSQL: pgjdbc/org/postgresql/test/jdbc2/MiscTest.java,v 1.23 2011/08/02 13:50:29 davecramer Exp $
 *
 *-------------------------------------------------------------------------
 */
@@ -66,6 +66,7 @@ public class MiscTest extends TestCase
             rs.close();
             stmt.cancel();
         }
+        TestUtil.closeDB(con);
     }
 
     public void testError() throws Exception
@@ -130,5 +131,6 @@ public class MiscTest extends TestCase
         con.commit();
         TestUtil.dropTable(con, "test_lock");
         con.close();
+        con2.close();
     }
 }
