@@ -1,9 +1,9 @@
 /*-------------------------------------------------------------------------
 *
-* Copyright (c) 2004-2005, PostgreSQL Global Development Group
+* Copyright (c) 2004-2011, PostgreSQL Global Development Group
 *
 * IDENTIFICATION
-*   $PostgreSQL: pgjdbc/org/postgresql/test/jdbc2/NotifyTest.java,v 1.7 2005/11/24 02:31:43 oliver Exp $
+*   $PostgreSQL: pgjdbc/org/postgresql/test/jdbc2/NotifyTest.java,v 1.11 2011/08/02 13:50:29 davecramer Exp $
 *
 *-------------------------------------------------------------------------
 */
@@ -49,6 +49,24 @@ public class NotifyTest extends TestCase
         stmt.close();
     }
 
+    public void testNotifyArgument() throws Exception
+    {
+        if (!TestUtil.haveMinimumServerVersion(conn, "9.0") || TestUtil.isProtocolVersion(conn, 2))
+            return;
+
+        Statement stmt = conn.createStatement();
+        stmt.executeUpdate("LISTEN mynotification");
+        stmt.executeUpdate("NOTIFY mynotification, 'message'");
+
+        PGNotification notifications[] = ((org.postgresql.PGConnection)conn).getNotifications();
+        assertNotNull(notifications);
+        assertEquals(1, notifications.length);
+        assertEquals("mynotification", notifications[0].getName());
+        assertEquals("message", notifications[0].getParameter());
+
+        stmt.close();
+    }
+
     public void testAsyncNotify() throws Exception
     {
         Statement stmt = conn.createStatement();
