@@ -1,9 +1,9 @@
 /*-------------------------------------------------------------------------
 *
-* Copyright (c) 2004-2008, PostgreSQL Global Development Group
+* Copyright (c) 2004-2011, PostgreSQL Global Development Group
 *
 * IDENTIFICATION
-*   $PostgreSQL: pgjdbc/org/postgresql/test/jdbc2/PreparedStatementTest.java,v 1.23 2009/04/20 21:44:09 jurka Exp $
+*   $PostgreSQL: pgjdbc/org/postgresql/test/jdbc2/PreparedStatementTest.java,v 1.25 2011/08/02 13:50:29 davecramer Exp $
 *
 *-------------------------------------------------------------------------
 */
@@ -801,6 +801,17 @@ public class PreparedStatementTest extends TestCase
         pstmt.close();
     }
 
+    /**
+     * With autoboxing this apparently happens more often now.
+     */
+    public void testSetObjectCharacter() throws SQLException
+    {
+        PreparedStatement ps = conn.prepareStatement("INSERT INTO texttable(te) VALUES (?)");
+        ps.setObject(1, new Character('z'));
+        ps.executeUpdate();
+        ps.close();
+    }
+
     /**
      * When we have parameters of unknown type and it's not using
      * the unnamed statement, we issue a protocol level statment
