@@ -1,9 +1,12 @@
-/*
- * Created on Jun 21, 2005
- *
- * TODO To change the template for this generated file go to
- * Window - Preferences - Java - Code Style - Code Templates
- */
+/*-------------------------------------------------------------------------
+*
+* Copyright (c) 2005-2011, PostgreSQL Global Development Group
+*
+* IDENTIFICATION
+*   $PostgreSQL: pgjdbc/org/postgresql/test/jdbc3/Jdbc3CallableStatementTest.java,v 1.7 2011/08/02 13:50:29 davecramer Exp $
+*
+*-------------------------------------------------------------------------
+*/
 package org.postgresql.test.jdbc3;
 
 import java.math.BigDecimal;
@@ -23,8 +26,6 @@ import junit.framework.TestCase;
 /**
  * @author davec
  *
- * TODO To change the template for this generated type comment go to
- * Window - Preferences - Java - Code Style - Code Templates
  */
 public class Jdbc3CallableStatementTest extends TestCase
 {
@@ -94,12 +95,11 @@ public class Jdbc3CallableStatementTest extends TestCase
         stmt.execute("drop function myiofunc(a INOUT int, b OUT int) ");
         stmt.execute("drop function myif(a INOUT int, b IN int)");
         stmt.close();
-        
+        TestUtil.closeDB(con);
     }
+
     public void testSomeInOut() throws Throwable
     {
-        
-                   
         CallableStatement call = con.prepareCall( "{ call test_somein_someout(?,?,?) }" ) ;
         
         call.registerOutParameter(2,Types.VARCHAR);
@@ -338,7 +338,7 @@ public class Jdbc3CallableStatementTest extends TestCase
             try
             {
                 Statement dstmt = con.createStatement();
-                dstmt.execute("drop function bit_proc()");
+                dstmt.execute("drop function insert_bit(boolean, boolean, boolean)");
             }
             catch (Exception ex){}
         }
@@ -393,7 +393,7 @@ public class Jdbc3CallableStatementTest extends TestCase
             try
             {
                 Statement dstmt = con.createStatement();
-                dstmt.execute("drop function bit_proc()");
+                dstmt.execute("drop function update_bit(boolean, boolean, boolean)");
             }
             catch (Exception ex){}
         }
@@ -553,7 +553,7 @@ public class Jdbc3CallableStatementTest extends TestCase
 		+ "return 0;"
 		+ " end;' "
 		+ "language 'plpgsql';";
-   	private final String dropUpdateReal = "drop function update_real_proc()";
+   	private final String dropUpdateReal = "drop function update_real_proc(float, float)";
    	private final double [] doubleValues =  {1.0E125, 1.0E-130};
    	private final float [] realValues = {(float)1.0E37,(float)1.0E-37};
    	private final int []intValues = {2147483647,-2147483648};
@@ -654,7 +654,7 @@ public class Jdbc3CallableStatementTest extends TestCase
             try
             {
                 Statement dstmt = con.createStatement();
-                dstmt.execute("drop function longvarbinary_proc()");
+                dstmt.execute("drop function updatefloat_proc(float, float)");
             }
             catch (Exception ex){}
         }
@@ -1100,4 +1100,19 @@ public class Jdbc3CallableStatementTest extends TestCase
             catch (Exception ex){}
         }
     }           
+
+    public void testMultipleOutExecutions() throws SQLException
+    {
+        CallableStatement cs = con.prepareCall("{call myiofunc(?, ?)}");
+        for (int i=0; i<10; i++) {
+            cs.registerOutParameter(1, Types.INTEGER);
+            cs.registerOutParameter(2, Types.INTEGER);
+            cs.setInt(1, i);
+            cs.execute();
+            assertEquals(1, cs.getInt(1));
+            assertEquals(i, cs.getInt(2));
+            cs.clearParameters();
+        }
+    }
+
 }
