@@ -1,3 +1,12 @@
+/*-------------------------------------------------------------------------
+*
+* Copyright (c) 2009-2011, PostgreSQL Global Development Group
+*
+* IDENTIFICATION
+*   $PostgreSQL: pgjdbc/org/postgresql/test/xa/XADataSourceTest.java,v 1.13 2011/08/02 20:26:00 davecramer Exp $
+*
+*-------------------------------------------------------------------------
+*/
 package org.postgresql.test.xa;
 
 import java.sql.Connection;
@@ -15,6 +24,7 @@ import javax.transaction.xa.Xid;
 
 
 import org.postgresql.test.TestUtil;
+import org.postgresql.test.jdbc2.optional.BaseDataSourceTest;
 import org.postgresql.xa.PGXADataSource;
 
 import junit.framework.TestCase;
@@ -33,12 +43,7 @@ public class XADataSourceTest extends TestCase {
         super(name);
 
         _ds = new PGXADataSource();
-        ((PGXADataSource)_ds).setServerName(TestUtil.getServer());
-        ((PGXADataSource)_ds).setPortNumber(TestUtil.getPort());
-        ((PGXADataSource)_ds).setUser(TestUtil.getUser());
-        ((PGXADataSource)_ds).setPassword(TestUtil.getPassword());
-        ((PGXADataSource)_ds).setDatabaseName(TestUtil.getDatabase());
-        ((PGXADataSource)_ds).setPrepareThreshold(TestUtil.getPrepareThreshold());
+        BaseDataSourceTest.setupDataSource((PGXADataSource)_ds);
     }
 
     protected void setUp() throws Exception {
