@@ -1,16 +1,27 @@
+/*-------------------------------------------------------------------------
+*
+* Copyright (c) 2009-2011, PostgreSQL Global Development Group
+*
+* IDENTIFICATION
+*   $PostgreSQL: pgjdbc/org/postgresql/xa/PGXAConnection.java,v 1.18 2011/08/02 20:26:00 davecramer Exp $
+*
+*-------------------------------------------------------------------------
+*/
 package org.postgresql.xa;
 
+import org.postgresql.PGConnection;
 import org.postgresql.ds.PGPooledConnection;
 import org.postgresql.core.BaseConnection;
+import org.postgresql.core.ProtocolConnection;
 import org.postgresql.core.Logger;
-
 import org.postgresql.util.GT;
+import org.postgresql.util.PSQLException;
+import org.postgresql.util.PSQLState;
 
-import java.sql.*;
 import javax.sql.*;
-
+import java.sql.*;
 import java.util.*;
-
+import java.lang.reflect.*;
 import javax.transaction.xa.Xid;
 import javax.transaction.xa.XAResource;
 import javax.transaction.xa.XAException;
@@ -76,7 +87,7 @@ public class PGXAConnection extends PGPooledConnection implements XAConnection,
         logger.debug("XAResource " + Integer.toHexString(this.hashCode()) + ": " + s);
     }
 
-    PGXAConnection(BaseConnection conn) throws SQLException
+    public PGXAConnection(BaseConnection conn) throws SQLException
     {
         super(conn, true, true);
         this.conn = conn;
@@ -101,13 +112,55 @@ public class PGXAConnection extends PGPooledConnection implements XAConnection,
         if(state == STATE_IDLE)
             conn.setAutoCommit(true);
 
-        return conn;
+        /*
+         * Wrap the connection in a proxy to forbid application from
+         * fiddling with transaction state directly during an XA transaction
+         */
+        ConnectionHandler handler = new ConnectionHandler(conn);
+        return (Connection)Proxy.newProxyInstance(getClass().getClassLoader(), new Class[]{Connection.class, PGConnection.class}, handler);
     }
 
     public XAResource getXAResource() {
         return this;
     }
 
+    /*
+     * A java.sql.Connection proxy class to forbid calls to transaction
+     * control methods while the connection is used for an XA transaction.
+     */
+    private class ConnectionHandler implements InvocationHandler
+    {
+	private Connection con;
+
+	public ConnectionHandler(Connection con)
+	{
+            this.con = con;
+        }
+
+        public Object invoke(Object proxy, Method method, Object[] args)
+        throws Throwable
+        {
+	    if (state != STATE_IDLE)
+            {
+                String methodName = method.getName();
+                if (methodName.equals("commit") ||
+                    methodName.equals("rollback") ||
+                    methodName.equals("setSavePoint") ||
+                    (methodName.equals("setAutoCommit") && ((Boolean) args[0]).booleanValue()))
+                {
+		    throw new PSQLException(GT.tr("Transaction control methods setAutoCommit(true), commit, rollback and setSavePoint not allowed while an XA transaction is active."),
+					    PSQLState.OBJECT_NOT_IN_STATE);
+                }
+            }
+            try {
+                return method.invoke(con, args);
+            } catch (InvocationTargetException ex) {
+                throw ex.getTargetException();
+            }
+        }
+    }
+
+
     /**** XAResource interface ****/
 
     /**
@@ -430,8 +483,10 @@ public class PGXAConnection extends PGPooledConnection implements XAConnection,
     private void commitPrepared(Xid xid) throws XAException {
         try
         {
-            // Check preconditions
-            if (state != STATE_IDLE)
+            // Check preconditions. The connection mustn't be used for another
+            // other XA or local transaction, or the COMMIT PREPARED command
+            // would mess it up.
+            if (state != STATE_IDLE || conn.getTransactionState() != ProtocolConnection.TRANSACTION_IDLE)
                 throw new PGXAException(GT.tr("Not implemented: 2nd phase commit must be issued using an idle connection"),
                                         XAException.XAER_RMERR);
 
